@@ -200,6 +200,8 @@ OC.L10N.register(
     "Failed to transcript call recording" : "Nun se pue trescribir la grabación de la llamada",
     "Accept" : "Aceptar",
     "Decline" : "Refugar",
+    "New message" : "Mensaxe nuevu",
+    "Notification" : "Avisu",
     "{user} reacted with {reaction}" : "{user} reaicionó con «{reaction}»",
     "{user} reacted with {reaction} in {call}" : "{user} reaicionó con «{reaction}» en: {call}",
     "{user} sent you a private message" : "{user} unvióte un mensaxe priváu",
@@ -531,7 +533,6 @@ OC.L10N.register(
     "Cancel" : "Encaboxar",
     "Now" : "Agora",
     "Loading …" : "Cargando…",
-    "No upcoming events" : "Nun hai eventos próximos",
     "From" : "De",
     "To" : "Pa",
     "Calendar" : "Calendariu",
@@ -625,7 +626,10 @@ OC.L10N.register(
     "Show Matterbridge log" : "Amosar el rexistru de Matterbridge",
     "Log content" : "Conteníu del rexistru",
     "Notifications" : "Avisos",
+    "Important conversation" : "Converación importante",
+    "Join" : "Xunise",
     "Error while creating the conversation" : "Hebo un error mentanto se creaba la conversación",
+    "Unread mentions" : "Menciones ensin lleer",
     "Create conversation" : "Crear una conversación",
     "Log in" : "Aniciar la sesión",
     "An error occurred while calling a phone number" : "Prodúxose un error mentanto se llamaba a un númberu de teléfonu",
@@ -645,8 +649,8 @@ OC.L10N.register(
     "You have no unread messages." : "Nun tienes nengún mensaxe ensin lleer.",
     "An error occurred while performing the search" : "Prodúxose un error mentanto se facía la busca",
     "Conversation list" : "Llista de conversaciones",
+    "Unread messages" : "Mensaxes ensin lleer",
     "New personal note" : "Nota personal nueva",
-    "Unread mentions" : "Menciones ensin lleer",
     "Talk settings" : "Configuración de Talk",
     "Users" : "Usuarios",
     "Groups" : "Grupos",
@@ -676,7 +680,6 @@ OC.L10N.register(
     "Message sent" : "Unvióse'l mensaxe",
     "Deleting message" : "Desaniciando'l mensaxe",
     "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
-    "Unread messages" : "Mensaxes ensin lleer",
     "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
     "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
     "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
@@ -765,7 +768,6 @@ OC.L10N.register(
     "Send a message to \"{roomName}\"" : "¿Quies unviar un mensaxe a «{roomName}»?",
     "Show list of participants" : "Amosar la llista de participantes",
     "The message was sent to \"{roomName}\"" : "El mensaxe unvióse a «{roomName}»",
-    "Join" : "Xunise",
     "Back to main room" : "Volver a la sala principal",
     "Message all rooms" : "Xestionar toles sales",
     "Start session" : "Aniciar la sesión",
@@ -852,6 +854,7 @@ OC.L10N.register(
     "Raise hand" : "Alzar la mano",
     "Lower hand" : "Baxar la mano",
     "Start recording" : "Aniciar la grabación",
+    "Keep" : "Caltener",
     "Open dialpad" : "Abrir el tecláu numbéricu",
     "Submit" : "Unviar",
     "Search …" : "Buscar…",
@@ -907,6 +910,7 @@ OC.L10N.register(
     "You and {user0} left the call" : "Tu y {user0} colestis de la canal",
     "You: {lastMessage}" : "Tu: {lastMessage}",
     "(edited)" : "(editóse)",
+    "Leave this page" : "Colar d'esta páxina",
     "In conversation" : "Na conversación",
     "Error while clearing conversation history" : "Hebo un error mentanto se borraba l'historial de la conversación",
     "Error occurred while allowing guests" : "Prodúxose un error mentanto se permitíen a los convidaos",
@@ -920,7 +924,6 @@ OC.L10N.register(
     "Could not post message: {errorMessage}" : "Nun se pudo espublizar el mensaxe: {errorMessage}",
     "Invitations sent" : "Unviáronse les invitaciones",
     "Error occurred when sending invitations" : "Prodúxose un error mentanto s'unviaben les conversaciones",
-    "Leave this page" : "Colar d'esta páxina",
     "An error occurred while requesting assistance" : "Prodúxose un error mentanto se solicitaba l'asistencia",
     "An error occurred while accepting an invitation" : "Prodúxose un error mentanto s'aceptaba una invitación",
     "An error occurred while submitting your vote" : "Prodúxose un error mentanto s'unviaba'l votu",
