@@ -45,6 +45,7 @@ OC.L10N.register(
     "An administrator removed the description" : "Ένας διαχειριστής κατάργησε την περιγραφή",
     "You started a call" : "Ξεκινήσατε μια κλήση",
     "{actor} started a call" : "Ο {actor} ξεκίνησε μια κλήση",
+    "Incoming call" : "Εισερχόμενη κλήση",
     "{actor} joined the call" : "Ο {actor} συμμετέχει στην κλήση",
     "You joined the call" : "Συμμετείχατε στην κλήση",
     "{actor} left the call" : "Ο {actor} αποχώρησε από την κλήση",
@@ -142,6 +143,9 @@ OC.L10N.register(
     "Dismiss notification" : "Αποδέσμευση ειδοποίησης",
     "Accept" : "Αποδοχή",
     "Decline" : "Απόρριψη",
+    "New message" : "Νέο μήνυμα",
+    "Reminder" : "Υπενθύμιση",
+    "Notification" : "Ειδοποιήσεις",
     "{user} in {call}" : "Ο {user} είναι σε {call}",
     "Deleted user in {call}" : "Διαγράφηκε ο χρήστης στην {call}",
     "{guest} (guest) in {call}" : "{guest} (επισκέπτης) στην {call}",
@@ -353,7 +357,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "Saint Martin (French part)",
     "Madagascar" : "Μαδαγασκάρη",
     "Marshall Islands" : "Marshall Islands",
-    "Macedonia, the former Yugoslav Republic of" : "Μακεδονία, πρώην Γιουγκοσλαβική Δημοκρατία της",
+    "North Macedonia" : "Δημοκρατία της Βόρειας Μακεδονίας",
     "Mali" : "Μάλι",
     "Myanmar" : "Myanmar",
     "Mongolia" : "Μογγολία",
@@ -577,7 +581,6 @@ OC.L10N.register(
     "Add participant \"{user}\"" : "Προσθήκη συμμετέχοντος \"{user}\"",
     "Now" : "Τώρα",
     "Loading …" : "Φόρτωση…",
-    "No upcoming events" : "Κανένα προσεχές γεγονός",
     "From" : "Από",
     "To" : "Έως",
     "Calendar" : "Ημερολόγιο",
@@ -637,10 +640,10 @@ OC.L10N.register(
     "Restricted" : "Περιορισμένο",
     "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Οι συμμετέχοντες μπορούν να συμμετέχουν σε κλήσεις, αλλά δεν μπορούν να ενεργοποιήσουν τον ήχο ή το βίντεο ούτε να μοιραστούν την οθόνη έως ότου ένας συντονιστής τους εκχωρήσει αυτά τα δικαιώματα.",
     "Advanced permissions" : "Προσαρμοσμένα δικαιώματα",
+    "Meeting" : "Συνάντηση",
     "Conversation settings" : "Ρυθμίσεις συνομιλίας",
     "Personal" : "Προσωπικός",
     "Always show the device preview screen before joining a call in this conversation." : "Να εμφανίζεται πάντα η οθόνη προεπισκόπησης της συσκευής πριν συμμετάσχετε σε μια κλήση σε αυτήν τη συνομιλία.",
-    "Meeting" : "Συνάντηση",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Επικίνδυνη ζώνη",
     "Do you really want to delete \"{displayName}\"?" : "Θέλετε σίγουρα να διαγράψετε το  \"{displayName}\"?",
@@ -657,8 +660,6 @@ OC.L10N.register(
     "Save password" : "Αποθήκευση κωδικού πρόσβασης",
     "Resend invitations" : "Επαναποστολή προσκλήσεων",
     "Error occurred when opening or limiting the conversation" : "Συνέβη σφάλμα κατά το άνοιγμα ή τον περιορισμό της συνομιλίας",
-    "Error occurred when restricting the conversation to moderator" : "Παρουσιάστηκε σφάλμα κατά τον περιορισμό της συνομιλίας σε επόπτη",
-    "Error occurred when opening the conversation to everyone" : "Παρουσιάστηκε σφάλμα κατά το άνοιγμα της συνομιλίας σε όλους",
     "Start time has been updated" : "Η ώρα έναρξης ενημερώθηκε",
     "Error occurred while updating start time" : "Παρουσιάστηκε σφάλμα κατά την ενημέρωση της ώρας έναρξης",
     "Meeting start time" : "Ώρα έναρξης της συνάντησης",
@@ -682,11 +683,15 @@ OC.L10N.register(
     "Log content" : "Περιεχόμενα αρχείου καταγραφής",
     "Notifications" : "Ειδοποιήσεις",
     "Notify about calls in this conversation" : "Να ειδοποιούμαι για κλήσεις σε αυτήν τη συνομιλία",
+    "Important conversation" : "Σημαντική συνομιλία",
     "SIP dial-in is now enabled" : "Το SIP dial-in είναι πλέον ενεργοποιημένο",
     "SIP dial-in is now disabled" : "Το SIP dial-in είναι πλέον απενεργοποιημένο",
     "Error occurred when enabling SIP dial-in" : "Παρουσιάστηκε σφάλμα κατά την ενεργοποίηση του SIP dial-in",
     "Error occurred when disabling SIP dial-in" : "Παρουσιάστηκε σφάλμα κατά την απενεργοποίηση του SIP dial-in",
+    "Join" : "Συμμετοχή",
     "Error while creating the conversation" : "Σφάλμα κατά τη δημιουργία συνομιλίας",
+    "Create a new conversation" : "Δημιουργία νέας συνομιλίας",
+    "Join open conversations" : "Συμμετοχή σε ανοικτές συνομιλίες",
     "Create conversation" : "Δημιουργία συνομιλίας",
     "Enter your name" : "Προσθέστε το όνομά σας",
     "Log in" : "Είσοδος",
@@ -700,6 +705,7 @@ OC.L10N.register(
     "No matches found" : "Δεν βρέθηκαν αντιστοιχίες",
     "An error occurred while performing the search" : "Παρουσιάστηκε σφάλμα κατά την αναζήτηση",
     "Conversation list" : "Λίστα συνομιλιών",
+    "Unread messages" : "Μη αναγνωσμένα μηνύματα",
     "Clear filter" : "Εκκαθάριση φίλτρου",
     "Talk settings" : "Ρυθμίσεις ομιλίας",
     "Users" : "Χρήστες",
@@ -728,7 +734,6 @@ OC.L10N.register(
     "Message deleted successfully" : "Το μήνυμα διαγράφηκε με επιτυχία ",
     "Message could not be deleted because it is too old" : "Δεν ήταν δυνατή η διαγραφή του μηνύματος επειδή είναι αρκετά παλιό ",
     "An error occurred while deleting the message" : "Προέκυψε ένα σφάλμα κατά τη διαγραφή του μηνύματος",
-    "Unread messages" : "Μη αναγνωσμένα μηνύματα",
     "Later today – {timeLocale}" : "Αργότερα σήμερα – {timeLocale}",
     "Set reminder for later today" : "Ορισμός υπενθύμισης για αργότερα σήμερα",
     "Tomorrow – {timeLocale}" : "Αύριο – {timeLocale}",
@@ -796,7 +801,6 @@ OC.L10N.register(
     "Anonymous poll" : "Ανώνυμη δημοσκόπηση",
     "Open poll" : "Ανοιχτή δημοσκόπηση",
     "The message has expired or has been deleted" : "Το μήνυμα έχει λήξει ή έχει διαγραφεί",
-    "Join" : "Συμμετοχή",
     "Disable lobby" : "Απενεργοποίηση αίθουσας αναμονής",
     "Settings for participant \"{user}\"" : "Ρυθμίσεις για συμμετέχοντα \"{user}\"",
     "Participant \"{user}\"" : "Συμμετέχων \"{user}\"",
@@ -854,6 +858,8 @@ OC.L10N.register(
     "Share my read-status and show the read-status of others" : "Μοίρασε την κατάσταση ανάγνωσής μου και δείξε την κατάσταση ανάγνωσης των άλλων",
     "Sounds" : "Ήχοι",
     "Play sounds when participants join or leave a call" : "Αναπαραγωγή ήχων όταν οι συμμετέχοντες εισέρχονται ή αποχωρούν από μια κλήση",
+    "Sounds can currently not be played on iPad and iPhone devices due to technical restrictions by the manufacturer." : "Οι ήχοι δεν μπορούν προς το παρόν να αναπαραχθούν σε συσκευές iPad και iPhone λόγω τεχνικών περιορισμών από τον κατασκευαστή.",
+    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Οι ήχοι για τις ειδοποιήσεις συνομιλίας και κλήσεων μπορούν να ρυθμιστούν στις προσωπικές ρυθμίσεις.",
     "Performance" : "Απόδοση",
     "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
     "Speed up your Talk experience with these quick shortcuts." : "Επιταχύνετε την εμπειρία σας στο Talk με αυτές τις γρήγορες συντομεύσεις.",
@@ -867,10 +873,12 @@ OC.L10N.register(
     "Push to talk or push to mute" : "Πιέστε για να μιλήσετε ή πιέστε για σίγαση",
     "Raise or lower hand" : "Σηκώστε ή κατεβάστε το χέρι",
     "Start call" : "Έναρξη κλήσης",
+    "End call" : "Τερματισμός κλήσης",
     "You will be able to join the call only after a moderator starts it." : "Μπορείτε να συμμετάσχετε στην κλήση μόνο μετά την εκκίνηση από τον συντονιστή.",
     "Recording" : "Καταγραφή",
     "Disable background blur" : "Απενεργοποίηση θολώματος φόντου",
     "Blur background" : "Θόλωμα φόντου",
+    "You are not allowed to enable screensharing" : "Δεν επιτρέπεται να ενεργοποιήσετε τον διαμοιρασμό οθόνης",
     "Screensharing options" : "Επιλογές διαμοιρασμού οθόνης",
     "Enable screensharing" : "Ενεργοποίηση διαμοιρασμού οθόνης",
     "Bad sent video and screen quality." : "Κακή ποιότητα βίντεο και διαμοιρασμού οθόνης.",
@@ -895,6 +903,8 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Προυσιάστηκε σφάλμα κατά την έναρξη του διαμοιρασμού οθόνης.",
     "Show your screen" : "Εμφάνιση της οθόνης σας",
     "Stop screensharing" : "Διακόψτε την κοινή χρήση της οθόνης",
+    "Exit full screen (F)" : "Έξοδος από πλήρη οθόνη (F)",
+    "Full screen (F)" : "Πλήρης οθόνη (F)",
     "Speaker view" : "Προβολή ομιλητή",
     "Grid view" : "Προβολή πλέγματος",
     "Raise hand" : "Σηκώστε το χέρι",
@@ -911,6 +921,7 @@ OC.L10N.register(
     "Duplicate session" : "Αντιγραφή συνεδρίας",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Συμμετείχατε στη συνομιλία σε άλλο παράθυρο ή συσκευή. Αυτήν τη στιγμή δεν υποστηρίζεται από το Nextcloud Talk, επομένως αυτή η συνεδρία τερματίστηκε.",
     "Join a conversation or start a new one" : "Συμμετέχετε σε συνομιλία ή ξεκινήστε μια νέα",
+    "Display name: {name}" : "Εμφανιζόμενο όνομα: {name}",
     "Nextcloud URL" : "Διεύθυνση URL του Nextcloud",
     "Nextcloud user" : "Χρήστης του Nextcloud",
     "User password" : "Συνθηματικό χρήστη",
@@ -924,6 +935,7 @@ OC.L10N.register(
     "Team name" : "Όνομα ομάδας",
     "Channel name" : "Όνομα καναλιού",
     "Rocket.Chat server URL" : "Διεύθυνση URL διακομιστή Rocket.Chat",
+    "User name or email address" : "Όνομα χρήστη ή διεύθυνση email",
     "Password" : "Συνθηματικό",
     "Rocket.Chat channel" : "Κανάλι Rocket.Chat",
     "Zulip server URL" : "Διεύθυνση URL διακομιστή Zulip",
@@ -963,8 +975,13 @@ OC.L10N.register(
     "Group" : "Ομάδα",
     "You: {lastMessage}" : "Εσείς: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Προσπαθείτε να συμμετάσχετε σε μια συνομιλία ενώ έχετε ενεργή συνεδρία σε άλλο παράθυρο ή συσκευή. Αυτή τη στιγμή δεν υποστηρίζεται αυτό από το Nextcloud Talk. Τι θέλετε να κάνετε;",
+    "Leave this page" : "Αποχώρηση από την σελίδα",
+    "Join here" : "Συμμετέχετε εδώ",
     "Error occurred while allowing guests" : "Παρουσιάστηκε σφάλμα κατά την άδεια των επισκεπτών",
     "Error occurred while disallowing guests" : "Παρουσιάστηκε σφάλμα κατά την απαγόρευση των επισκεπτών",
+    "Error occurred when restricting the conversation to moderator" : "Παρουσιάστηκε σφάλμα κατά τον περιορισμό της συνομιλίας σε επόπτη",
+    "Error occurred when opening the conversation to everyone" : "Παρουσιάστηκε σφάλμα κατά το άνοιγμα της συνομιλίας σε όλους",
     "Conversation password has been saved" : "Ο κωδικός πρόσβασης συνομιλίας έχει αποθηκευτεί",
     "Conversation password has been removed" : "Ο κωδικός πρόσβασης συνομιλίας έχει αφαιρεθεί",
     "Error occurred while saving conversation password" : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση του κωδικού πρόσβασης συνομιλίας",
@@ -976,9 +993,6 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Παρουσιάστηκε σφάλμα κατά την ανάκτηση των συμμετεχόντων",
     "Invitations sent" : "Η προσκλήσεις στάλθηκαν",
     "Error occurred when sending invitations" : "Παρουσιάστηκε σφάλμα κατά την αποστολή προσκλήσεων",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Προσπαθείτε να συμμετάσχετε σε μια συνομιλία ενώ έχετε ενεργή συνεδρία σε άλλο παράθυρο ή συσκευή. Αυτή τη στιγμή δεν υποστηρίζεται αυτό από το Nextcloud Talk. Τι θέλετε να κάνετε;",
-    "Leave this page" : "Αποχώρηση από την σελίδα",
-    "Join here" : "Συμμετέχετε εδώ",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Ο περιηγητής που χρησιμοποιείτε δεν υποστηρίζεται πλήρως από το Nextcloud Talk. Παρακαλώ χρησιμοποιήστε την τελευταία έκδοση του Mozilla Firefox, Microsoft Edge, Google Chrome ή Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Χάθηκε η σύνδεση με τον διακομιστή σηματοδοσίας. Προσπάθεια επανασύνδεσης.",
     "Establishing signaling connection is taking longer than expected …" : "Η διαδικασία σύνδεσης διαρκεί περισσότερο από το αναμενόμενο ...",
