@@ -88,6 +88,8 @@ OC.L10N.register(
     "Dismiss notification" : "Descartar notificación",
     "Accept" : "Aceptar",
     "Decline" : "Rechazar",
+    "New message" : "Mensaje nuevo",
+    "Reminder" : "Recordatorio",
     "{user} sent you a private message" : "{user} te envió un mensaje privado",
     "{user} mentioned you in a private conversation" : "{user} te mencionó en una conversación privada",
     "{user} invited you to a group conversation: {call}" : "{user} te invitó a una conversación de grupo: {call}",
@@ -355,7 +357,6 @@ OC.L10N.register(
     "Back" : "Atrás",
     "Cancel" : "Cancelar",
     "Loading …" : "Cargando …",
-    "No upcoming events" : "No hay eventos próximos",
     "From" : "De",
     "To" : "Para",
     "Calendar" : "Calendario",
@@ -385,8 +386,8 @@ OC.L10N.register(
     "Choose" : "Seleccionar",
     "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
     "Restricted" : "Restringido",
-    "Personal" : "Personal",
     "Meeting" : "Reunión",
+    "Personal" : "Personal",
     "Leave conversation" : "Dejar la conversación",
     "Delete conversation" : "Borrar conversación",
     "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
@@ -397,13 +398,13 @@ OC.L10N.register(
     "Delete" : "Eliminar",
     "Log content" : "Contenido de bitácoras",
     "Notifications" : "Notificaciones",
+    "Unread mentions" : "Menciones sin leer",
     "Enter your name" : "Ingrese su nombre",
     "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
     "Unread" : "No leído",
     "Clear filter" : "Limpiar filtro",
-    "Unread mentions" : "Menciones sin leer",
     "Users" : " Usuarios",
     "Groups" : "Grupos",
     "Teams" : "Equipos",
@@ -473,6 +474,7 @@ OC.L10N.register(
     "Stop screensharing" : "Dejar de compartir la pantalla",
     "Exit full screen (F)" : "Salir de pantalla completa (F)",
     "Grid view" : "Vista de cuadrícula",
+    "Keep" : "Mantener",
     "Submit" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "Talk conversation" : "Conversación de Talk",
