@@ -212,6 +212,9 @@ OC.L10N.register(
     "Accept" : "Hyväksy",
     "Decline" : "Kieltäydy",
     "{user1} invited you to a federated conversation" : "{user1} kutsui sinut federoituun keskusteluun",
+    "New message" : "Uusi viesti",
+    "Reminder" : "Muistutus",
+    "Notification" : "Ilmoitus",
     "{user} in {call}" : "{user} puhelussa {call}",
     "{guest} (guest) in {call}" : "{guest} (vieras) puhelussa {call}",
     "Guest in {call}" : "Vieras puhelussa {call}",
@@ -615,7 +618,6 @@ OC.L10N.register(
     "Add participant \"{user}\"" : "Lisää osallistuja \"{user}\"",
     "Now" : "Nyt",
     "Loading …" : "Ladataan…",
-    "No upcoming events" : "Ei tulevia tapahtumia",
     "From" : "Lähettäjä",
     "To" : "Vastaanottaja",
     "Calendar" : "Kalenteri",
@@ -715,11 +717,11 @@ OC.L10N.register(
     "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Osallistujat voivat liittyä puheluihin, mutta eivät voi ottaa ääntä tai videota käyttöön tai jakaa näyttönsä sisältöä, ennen kuin moderaattori on antanut siihen luvan.",
     "Advanced permissions" : "Edistyneet oikeudet",
     "Edit permissions" : "Muokkaa oikeuksia",
+    "Meeting" : "Kokous",
     "Conversation settings" : "Keskustelun asetukset",
     "Basic Info" : "Perustiedot",
     "Personal" : "Henkilökohtainen",
     "Always show the device preview screen before joining a call in this conversation." : "Näytä aina laitteen esikatselunäkymä ennen liittymistä puheluun tässä keskustelussa.",
-    "Meeting" : "Kokous",
     "Breakout Rooms" : "Pienryhmätilat",
     "Matterbridge" : "Matterbridge",
     "Bots" : "Botit",
@@ -783,17 +785,22 @@ OC.L10N.register(
     "Log content" : "Lokin sisältö",
     "Notifications" : "Ilmoitukset",
     "Notify about calls in this conversation" : "llmoita puheluista tässä keskustelussa",
+    "Important conversation" : "Tärkeä keskustelu",
     "SIP dial-in is now possible without PIN requirement" : "SIP-sisäänsoitto on nyt mahdollista ilman PIN-koodin vaatimusta",
     "SIP dial-in is now enabled" : "SIP-sisäänsoitto on nyt käytössä",
     "SIP dial-in is now disabled" : "SIP-sisäänsoitto on nyt pois käytöstä",
     "Phone and SIP dial-in" : "Puhelin- ja SIP-sisäänsoitto",
     "Enable phone and SIP dial-in" : "Käytä puhelimella ja SIP:illä sisäänsoittoa",
     "Allow to dial-in without a PIN" : "Salli sisäänsoitto ilman PIN-koodia",
+    "Join" : "Liity",
     "Error while creating the conversation" : "Virhe keskustelua luotaessa",
+    "Create a new conversation" : "Luo uusi keskustelu",
+    "Join open conversations" : "Liity avoimiin keskusteluihin",
+    "Call a phone number" : "Soita puhelinnumeroon",
+    "Unread mentions" : "Lukemattomat maininnat",
     "Create conversation" : "Luo keskustelu",
     "Enter your name" : "Kirjoita nimesi",
     "Log in" : "Kirjaudu sisään",
-    "Call a phone number" : "Soita puhelinnumeroon",
     "Creating the conversation …" : "Luodaan keskustelu…",
     "Mark as read" : "Merkitse luetuksi",
     "Mark as unread" : "Merkitse lukemattomaksi",
@@ -812,14 +819,10 @@ OC.L10N.register(
     "You have no unread messages." : "Sinulla ei ole lukemattomia viestejä.",
     "An error occurred while performing the search" : "Hakua suorittaessa tapahtui virhe",
     "Conversation list" : "Keskustelulista",
-    "Filter unread mentions" : "Suodata lukemattomat maininnat",
-    "Filter unread messages" : "Suodata lukemattomat viestit",
+    "Unread messages" : "Lukemattomat viestit",
     "Clear filters" : "Tyhjennä suodattimet",
-    "Create a new conversation" : "Luo uusi keskustelu",
     "New personal note" : "Uusi henkilökohtainen muistiinpano",
-    "Join open conversations" : "Liity avoimiin keskusteluihin",
     "Clear filter" : "Tyhjennä suodatin",
-    "Unread mentions" : "Lukemattomat maininnat",
     "Talk settings" : "Talk-asetukset",
     "Users" : "Käyttäjät",
     "Groups" : "Ryhmät",
@@ -881,7 +884,6 @@ OC.L10N.register(
     "Only normal chat messages can be deleted" : "Vain normaaleja keskustelun viestejä on mahdollista poistaa",
     "An error occurred while deleting the message" : "Virhe viestiä poistaessa",
     "Show or collapse system messages" : "Näytä tai piilota järjestelmäviestit",
-    "Unread messages" : "Lukemattomat viestit",
     "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
     "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
     "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
@@ -1016,7 +1018,6 @@ OC.L10N.register(
     "Show list of participants" : "Näytä osallistujaluettelo",
     "Assistance requested in {roomName}" : "Apua pyydetty pienryhmätilassa {roomName}",
     "The message was sent to \"{roomName}\"" : "Viesti lähetettiin huoneeseen \"{roomName}\"",
-    "Join" : "Liity",
     "Send message to room" : "Lähetä viesti huoneeseen",
     "Manage breakout rooms" : "Hallitse pienryhmätiloja",
     "Back to main room" : "Takaisin päähuoneeseen",
@@ -1247,6 +1248,8 @@ OC.L10N.register(
     "(edited)" : "(muokattu)",
     "(edited by you)" : "(muokattu toimestasi)",
     "(edited by a deleted user)" : "(muokattu poistetun käyttäjän toimesta)",
+    "Leave this page" : "Poistu tältä sivulta",
+    "Join here" : "Liity tähän",
     "The recording failed. Please contact your administrator." : "Tallennus epäonnistui. Ole yhteydessä ylläpitoon.",
     "Search in conversation: {conversation}" : "Etsi keskustelusta: {conversation}",
     "Error while clearing conversation history" : "Virhe keskusteluhistoriaa siivotessa",
@@ -1266,8 +1269,6 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Virhe osallistujia noudettaessa",
     "Invitations sent" : "Kutsut lähetetty",
     "Error occurred when sending invitations" : "Kutsujen lähetyksessä tapahtui virhe",
-    "Leave this page" : "Poistu tältä sivulta",
-    "Join here" : "Liity tähän",
     "An error occurred while creating breakout rooms" : "Pienryhmätiloja luotaessa tapahtui virhe",
     "{guest} (guest)" : "{guest} (vieras)",
     "Failed to add reaction" : "Reaktion lisääminen epäonnistui",
@@ -1309,6 +1310,8 @@ OC.L10N.register(
     "Join »%s«" : "Liity »%s«",
     "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
     "Copy conversation link" : "Kopioi keskustelulinkki",
+    "Filter unread mentions" : "Suodata lukemattomat maininnat",
+    "Filter unread messages" : "Suodata lukemattomat viestit",
     "Close" : "Sulje",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk päivitettiin, lataa sivu uudelleen",
     "An error happened when trying to share your file" : "Virhe yrittäessä jakaa tiedostoasi",
