@@ -74,7 +74,7 @@ OC.L10N.register(
     "No unread mentions" : "אין אזכורים שלא נקראו",
     "Call in progress" : "מתנהלת שיחה",
     "Conversation invitation" : "הזמנה לדיון",
-    "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
+    "Description" : "תיאור",
     "Meeting ID" : "מזהה פגישה",
     "Password request: %s" : "בקשת ססמה: %s",
     "Private conversation" : "דיון פרטי",
@@ -82,6 +82,8 @@ OC.L10N.register(
     "Dismiss notification" : "התעלמות מהתראה",
     "Accept" : "אשר",
     "Decline" : "דחייה",
+    "New message" : "הודעה חדשה",
+    "Notification" : "הוֹדָעָה",
     "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
     "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
     "Join call" : "הצטרפות לשיחה",
@@ -235,6 +237,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "סן מרטן (העבר הצרפתי)",
     "Madagascar" : "מדגסקר",
     "Marshall Islands" : "איי מרשל",
+    "North Macedonia" : "מקדוניה הצפונית",
     "Mali" : "מאלי",
     "Myanmar" : "מיאנמר",
     "Mongolia" : "מונגוליה",
@@ -363,7 +366,6 @@ OC.L10N.register(
     "Disabled" : "מושבת",
     "State" : "מצב",
     "Name" : "שם",
-    "Description" : "תיאור",
     "Beta" : "בטא",
     "Permissions" : "הרשאות",
     "All messages" : "כל ההודעות",
@@ -401,7 +403,6 @@ OC.L10N.register(
     "Back" : "חזרה",
     "Cancel" : "ביטול",
     "Loading …" : "בטעינה…",
-    "No upcoming events" : "אין אירועים בזמן הקרוב",
     "From" : "מאת",
     "To" : "אל",
     "Calendar" : "לוח שנה",
@@ -430,9 +431,9 @@ OC.L10N.register(
     "Disable" : "השבתה",
     "Choose" : "בחר",
     "Restricted" : "מוגבלת",
+    "Meeting" : "מפגש",
     "Conversation settings" : "הגדרות דיון",
     "Personal" : "אישי",
-    "Meeting" : "מפגש",
     "Leave conversation" : "יציאה מהדיון",
     "Delete conversation" : "מחיקת דיון",
     "_%n hour_::_%n hours_" : ["שעה","שעתיים","%n שעות"],
@@ -447,6 +448,8 @@ OC.L10N.register(
     "Bridge saved" : "הגישור נשמר",
     "Log content" : "תוכן הרישום",
     "Notifications" : "התראות",
+    "Important conversation" : "דיון חשוב",
+    "Join" : "הצטרף",
     "Error while creating the conversation" : "שגיאה ביצירת הדיון",
     "Create conversation" : "יצירת דיון",
     "Enter your name" : "נא למלא את שמך",
@@ -457,6 +460,7 @@ OC.L10N.register(
     "Add to favorites" : "הוספה למועדפים",
     "No matches found" : "לא נמצאו התאמות",
     "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
+    "Unread messages" : "הודעות שלא נקראו",
     "Clear filter" : "מחיקת מסנן",
     "Users" : "משתמשים",
     "Groups" : "קבוצות",
@@ -470,7 +474,6 @@ OC.L10N.register(
     "Files" : "קבצים",
     "Message sent" : "הודעה נשלחה",
     "Deleting message" : "ההודעה נמחקה",
-    "Unread messages" : "הודעות שלא נקראו",
     "Reply" : "תגובה",
     "Go to file" : "מעבר לקובץ",
     "Translate" : "תרגום",
@@ -495,7 +498,6 @@ OC.L10N.register(
     "Create poll" : "יצירת סקר",
     "Settings" : "הגדרות",
     "Anonymous poll" : "סקר אלמוני",
-    "Join" : "הצטרף",
     "moderator" : "מפקח/ת",
     "guest" : "אורח",
     "Remove group and members" : "הסרת קבוצה וחברים",
@@ -540,6 +542,7 @@ OC.L10N.register(
     "Speaker view" : "תצוגת דובר",
     "Grid view" : "תצוגת טבלה",
     "Mute others" : "השתקה של אחרים",
+    "Keep" : "שימור",
     "Select a region" : "נא לבחור איזור",
     "Submit" : "שליחה",
     "Message without mention" : "הודעה ללא אזכור",
@@ -604,23 +607,9 @@ OC.L10N.register(
     "__language_name__" : "עברית",
     "Tasks" : "משימות",
     "Notes" : "פתקים",
-    "There are currently no commands available." : "אין פקודות זמינות.",
-    "The command does not exist" : "הפקודה לא קיימת",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "אירעה שגיאה בעת הפעלת הפקודה. נא לבקש מהנהלת המערכת לבדוק את יומן התיעוד.",
+    "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
     "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
-    "Moderators" : "מפקחים",
-    "Commands" : "פקודות",
-    "Command" : "פקודה",
-    "Script" : "סקריפט",
-    "Response to" : "תגובה אל",
-    "Enabled for" : "מופעל עבור",
     "Copy conversation link" : "העתקת קישור דיון",
-    "Channel ID or name" : "מזהה ערוץ או שם",
-    "Loading" : "בטעינה",
-    "Close" : "סגירה",
-    "Password protect" : "הגנה בססמה",
-    "TURN server" : "שרת TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
-    "Signaling servers" : "שרתי איתות"
+    "Close" : "סגירה"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
