@@ -174,6 +174,8 @@ OC.L10N.register(
     "Dismiss notification" : "Zanemari obavijest",
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
+    "New message" : "Nova poruka",
+    "Reminder" : "Podsjetnik",
     "{user} in {call}" : "{user} u {call}",
     "Deleted user in {call}" : "Izbrisan korisnik u {call}",
     "{guest} (guest) in {call}" : "{guest} (gost) u {call}",
@@ -386,7 +388,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "Sveti Martin (francuski dio)",
     "Madagascar" : "Madagaskar",
     "Marshall Islands" : "Maršalovi Otoci",
-    "Macedonia, the former Yugoslav Republic of" : "Makedonija, bivša jugoslavenska republika",
+    "North Macedonia" : "Sjeverna Makedonija",
     "Mali" : "Mali",
     "Myanmar" : "Mjanmar",
     "Mongolia" : "Mongolija",
@@ -609,7 +611,6 @@ OC.L10N.register(
     "Cancel" : "Odustani",
     "Add participant \"{user}\"" : "Dodaj sudionika „{user}”",
     "Loading …" : "Učitavanje…",
-    "No upcoming events" : "Nema nadolazećih događaja",
     "From" : "Od",
     "To" : "Do",
     "Calendar" : "Kalendar",
@@ -672,10 +673,10 @@ OC.L10N.register(
     "Restricted" : "Ograničeno",
     "Advanced permissions" : "Napredna dopuštenja",
     "Edit permissions" : "Uredi dopuštenja",
+    "Meeting" : "Sastanak",
     "Conversation settings" : "Postavke razgovora",
     "Personal" : "Osobno",
     "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
-    "Meeting" : "Sastanak",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zona opasnosti",
     "Do you really want to delete \"{displayName}\"?" : "Želite li zaista izbrisati „{displayName}“?",
@@ -697,8 +698,6 @@ OC.L10N.register(
     "Save password" : "Spremi zaporku",
     "Resend invitations" : "Ponovno pošalji pozivnice",
     "Error occurred when opening or limiting the conversation" : "Došlo je do pogreške pri otvaranju ili ograničavanju razgovora",
-    "Error occurred when restricting the conversation to moderator" : "Došlo je do pogreške pri ograničavanju razgovora samo na moderatore",
-    "Error occurred when opening the conversation to everyone" : "Došlo je do pogreške pri otvaranju razgovora svima",
     "Start time has been updated" : "Vrijeme početka je ažurirano",
     "Error occurred while updating start time" : "Došlo je do pogreške pri ažuriranju vremena početka",
     "Meeting start time" : "Vrijeme početka sastanka",
@@ -723,11 +722,14 @@ OC.L10N.register(
     "Log content" : "Sadržaj zapisa",
     "Notifications" : "Obavijesti",
     "Notify about calls in this conversation" : "Obavijesti o pozivima u ovom razgovoru",
+    "Important conversation" : "Važan razgovor",
     "SIP dial-in is now enabled" : "Povezivanje putem SIP-a je omogućeno",
     "SIP dial-in is now disabled" : "Povezivanje putem SIP-a je onemogućeno",
     "Error occurred when enabling SIP dial-in" : "Došlo je do pogreške pri omogućavanju povezivanja putem SIP-a",
     "Error occurred when disabling SIP dial-in" : "Došlo je do pogreške pri onemogućavanju povezivanja putem SIP-a",
+    "Join" : "Pridruži se",
     "Error while creating the conversation" : "Pogreška pri stvaranju razgovora",
+    "Unread mentions" : "Nepročitana spominjanja",
     "Create conversation" : "Stvori razgovor",
     "Enter your name" : "Unesite svoje ime",
     "Log in" : "Prijavite se",
@@ -741,8 +743,8 @@ OC.L10N.register(
     "No conversations found" : "Nije pronađen nijedan razgovor",
     "An error occurred while performing the search" : "Došlo je do pogreške pri pretraživanju",
     "Conversation list" : "Popis razgovora",
+    "Unread messages" : "Nepročitane poruke",
     "Clear filter" : "Ukloni filtar",
-    "Unread mentions" : "Nepročitana spominjanja",
     "Talk settings" : "Postavke razgovora",
     "Users" : "Korisnici",
     "Groups" : "Grupe",
@@ -771,7 +773,6 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Poruku nije moguće izbrisati jer je prestara",
     "Only normal chat messages can be deleted" : "Mogu se izbrisati samo uobičajene razmijenjene poruke",
     "An error occurred while deleting the message" : "Došlo je do pogreške pri brisanju poruke",
-    "Unread messages" : "Nepročitane poruke",
     "Reply" : "Odgovori",
     "Reply privately" : "Odgovori privatno",
     "Copy message link" : "Kopiraj poveznicu poruke",
@@ -834,7 +835,6 @@ OC.L10N.register(
     "Updating permissions" : "Ažuriranje dopuštenja",
     "Settings" : "Postavke",
     "Anonymous poll" : "Anonimna anketa",
-    "Join" : "Pridruži se",
     "Disable lobby" : "Onemogući predvorje",
     "Settings for participant \"{user}\"" : "Postavke sudionika „{user}”",
     "Participant \"{user}\"" : "Sudionik „{user}”",
@@ -1016,9 +1016,14 @@ OC.L10N.register(
     "Group" : "Grupa",
     "You: {lastMessage}" : "Vi: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokušavate se pridružiti razgovoru dok imate otvorenu sesiju u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju. Što želite učiniti?",
+    "Leave this page" : "Napusti ovu stranicu",
+    "Join here" : "Pridruži se ovdje",
     "Error while clearing conversation history" : "Pogreška pri brisanju povijesti razgovora",
     "Error occurred while allowing guests" : "Došlo je do pogreške pri omogućavanju pristupa gostima",
     "Error occurred while disallowing guests" : "Došlo je do pogreške pri onemogućavanju pristupa gostima",
+    "Error occurred when restricting the conversation to moderator" : "Došlo je do pogreške pri ograničavanju razgovora samo na moderatore",
+    "Error occurred when opening the conversation to everyone" : "Došlo je do pogreške pri otvaranju razgovora svima",
     "Conversation password has been saved" : "Zaporka razgovora je spremljena",
     "Conversation password has been removed" : "Zaporka razgovora je uklonjena",
     "Error occurred while saving conversation password" : "Došlo je do pogreške pri spremanju zaporke razgovora",
@@ -1030,9 +1035,6 @@ OC.L10N.register(
     "Could not send invitation to {actorId}" : "Nije moguće poslati pozivnicu za {actorId}",
     "Invitations sent" : "Pozivnice su poslane",
     "Error occurred when sending invitations" : "Došlo je do pogreške pri slanju pozivnica",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokušavate se pridružiti razgovoru dok imate otvorenu sesiju u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju. Što želite učiniti?",
-    "Leave this page" : "Napusti ovu stranicu",
-    "Join here" : "Pridruži se ovdje",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk ne podržava trenutni preglednik. Preuzmite najnoviju inačicu preglednika Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ili Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušavam se ponovno povezati.",
     "Establishing signaling connection is taking longer than expected …" : "Uspostavljanje signalne veze traje duže od očekivanog…",
