@@ -203,6 +203,9 @@ OC.L10N.register(
     "Dismiss notification" : "Cancella notifica",
     "Accept" : "Accetta",
     "Decline" : "Rifiuta",
+    "New message" : "Nuovo messaggio",
+    "Reminder" : "Promemoria",
+    "Notification" : "Notifica",
     "{user} in {call}" : "{user} in {call}",
     "Deleted user in {call}" : "Utente eliminato in {call}",
     "{guest} (guest) in {call}" : "{guest} (guest) in {call}",
@@ -423,7 +426,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "Saint Martin (parte francese)",
     "Madagascar" : "Madagascar",
     "Marshall Islands" : "Isole Marshall",
-    "Macedonia, the former Yugoslav Republic of" : "Macedonia, Ex Repubblica Jugoslava di",
+    "North Macedonia" : "Macedonia del Nord",
     "Mali" : "Mali",
     "Myanmar" : "Myanmar",
     "Mongolia" : "Mongolia",
@@ -665,7 +668,6 @@ OC.L10N.register(
     "Add participant \"{user}\"" : "Aggiungi il partecipante \"{user}\"",
     "Now" : "Ora",
     "Loading …" : "Caricamento…",
-    "No upcoming events" : "Nessun prossimo evento",
     "From" : "Da",
     "To" : "A",
     "Calendar" : "Calendario",
@@ -744,12 +746,12 @@ OC.L10N.register(
     "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "I partecipanti possono partecipare alle chiamate, ma non possono abilitare né audio né video né condividere lo schermo finché un moderatore non concede loro manualmente i permessi.",
     "Advanced permissions" : "Permessi avanzati",
     "Edit permissions" : "Modifica permessi",
+    "Meeting" : "Riunione",
     "Conversation settings" : "Impostazioni conversazione",
     "Basic Info" : "Informazioni di base",
     "Personal" : "Personale",
     "Always show the device preview screen before joining a call in this conversation." : "Mostra sempre la schermata di anteprima del dispositivo prima di partecipare a una chiamata in questa conversazione.",
     "Moderation" : "Moderazione",
-    "Meeting" : "Riunione",
     "Matterbridge" : "Matterbridge",
     "Bots" : "Bot",
     "Danger zone" : "Zona pericolosa",
@@ -778,8 +780,6 @@ OC.L10N.register(
     "This conversation is limited to the current participants" : "Questa conversazione è limitata ai partecipanti attuali",
     "Error occurred when opening or limiting the conversation" : "Si è verificato un errore durante l'apertura o la limitazione della conversazione",
     "Open conversation to registered users, showing it in search results" : " Permetti l’accesso alla conversazione agli utenti registrati, mostrandoli tra i risultati di ricerca",
-    "Error occurred when restricting the conversation to moderator" : "Si è verificato un errore durante la limitazione della conversazione al moderatore",
-    "Error occurred when opening the conversation to everyone" : "Si è verificato un errore durante l'apertura della conversazione a tutti",
     "Start time has been updated" : "L'orario di inizio è stato aggiornato",
     "Error occurred while updating start time" : "Si è verificato un errore durante l'aggiornamento dell'orario di inizio",
     "Enable lobby, restricting the conversation to moderators" : "Abilita la lobby, limitando la conversazione ai moderatori",
@@ -806,12 +806,16 @@ OC.L10N.register(
     "Log content" : "Contenuto dei log",
     "Notifications" : "Notifiche",
     "Notify about calls in this conversation" : "Notifica delle chiamate in questa conversazione",
+    "Important conversation" : "Conversazione importante",
     "Recording consent is required for all calls" : "Il permesso di registrazione è richiesto per tutte le call",
     "SIP dial-in is now enabled" : "L'accesso SIP è ora abilitato",
     "SIP dial-in is now disabled" : "L'accesso SIP è ora disabilitato",
     "Error occurred when enabling SIP dial-in" : "Si è verificato un errore durante l'abilitazione dell'accesso SIP",
     "Error occurred when disabling SIP dial-in" : "Si è verificato un errore durante la disabilitazione dell'accesso SIP",
+    "Join" : "Partecipa",
     "Error while creating the conversation" : "Errore durante la creazione della conversazione",
+    "Create a new conversation" : "Crea una nuova conversazione",
+    "Unread mentions" : "Menzioni non lette",
     "Create conversation" : "Crea conversazione",
     "Enter your name" : "Digita il tuo nome",
     "Log in" : "Login",
@@ -827,9 +831,8 @@ OC.L10N.register(
     "No conversations found" : "Nessuna conversazione trovata",
     "An error occurred while performing the search" : "Si è verificato un errore durante l'esecuzione della ricerca",
     "Conversation list" : "Elenco delle conversazioni",
-    "Create a new conversation" : "Crea una nuova conversazione",
+    "Unread messages" : "Messaggi non letti",
     "Clear filter" : "Pulisci il filtro",
-    "Unread mentions" : "Menzioni non lette",
     "Talk settings" : "Impostazioni di Talk",
     "Users" : "Utenti",
     "Groups" : "Gruppi",
@@ -862,7 +865,6 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Impossibile eliminare il messaggio perché è troppo datato",
     "Only normal chat messages can be deleted" : "È possibile eliminare solo i normali messaggi di chat",
     "An error occurred while deleting the message" : "Si è verificato un errore durante l'eliminazione del messaggio",
-    "Unread messages" : "Messaggi non letti",
     "Later today – {timeLocale}" : "Oggi – {timeLocale}",
     "Set reminder for later today" : "Imposta promemoria per più tardi oggi",
     "Tomorrow – {timeLocale}" : "Domani – {timeLocale}",
@@ -948,7 +950,6 @@ OC.L10N.register(
     "Settings" : "Impostazioni",
     "Anonymous poll" : "Sondaggio anonimo",
     "Open poll" : "Apri sondaggio",
-    "Join" : "Partecipa",
     "Disable lobby" : "Disabilita l'ingresso",
     "Settings for participant \"{user}\"" : "Impostazioni per il partecipante \"{user}\"",
     "Participant \"{user}\"" : "Partecipante \"{user}\"",
@@ -1157,9 +1158,14 @@ OC.L10N.register(
     "Team" : "Team",
     "You: {lastMessage}" : "Tu: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Stai tentando di partecipare a una conversazione mentre hai una sessione attiva in un'altra finestra o dispositivo. Questo non è attualmente supportato da Nextcloud Talk. Che cosa vuoi fare?",
+    "Leave this page" : "Abbandona questa pagina",
+    "Join here" : "Unisciti qui",
     "Error while clearing conversation history" : "Errore durante la cancellazione della cronologia della conversazione",
     "Error occurred while allowing guests" : "Si è verificato un errore durante l'autorizzazione degli ospiti",
     "Error occurred while disallowing guests" : "Si è verificato un errore durante la disabilitazione degli ospiti",
+    "Error occurred when restricting the conversation to moderator" : "Si è verificato un errore durante la limitazione della conversazione al moderatore",
+    "Error occurred when opening the conversation to everyone" : "Si è verificato un errore durante l'apertura della conversazione a tutti",
     "Conversation password has been saved" : "La password della conversazione è stata salvata",
     "Conversation password has been removed" : "La password della conversazione è stata rimossa",
     "Error occurred while saving conversation password" : "Si è verificato un errore durante il salvataggio della password della conversazione",
@@ -1171,9 +1177,6 @@ OC.L10N.register(
     "Could not send invitation to {actorId}" : "Impossibile inviare l'invito a {actorId}",
     "Invitations sent" : "Inviti inviati",
     "Error occurred when sending invitations" : "Si è verificato un errore durante l'invio degli inviti",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Stai tentando di partecipare a una conversazione mentre hai una sessione attiva in un'altra finestra o dispositivo. Questo non è attualmente supportato da Nextcloud Talk. Che cosa vuoi fare?",
-    "Leave this page" : "Abbandona questa pagina",
-    "Join here" : "Unisciti qui",
     "Failed to add reaction" : "Impossibile aggiungere la reazione",
     "Failed to remove reaction" : "Impossibile rimuovere la reazione",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Il browser che stai utilizzando non è completamente supportato da Nextcloud Talk. Usa l'ultima versione di Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
