@@ -170,6 +170,9 @@ OC.L10N.register(
     "Dismiss notification" : "Atmesti pranešimą",
     "Accept" : "Priimti",
     "Decline" : "Atmesti",
+    "New message" : "Naujas laiškas",
+    "Reminder" : "Priminimas",
+    "Notification" : "Pranešimas",
     "{user} sent you a private message" : "{user} išsiuntė jums privačią žinutę",
     "{user} sent a message in conversation {call}" : "{user} išsiuntė žinutę pokalbyje {call}",
     "A deleted user sent a message in conversation {call}" : "Ištrintas naudotojas išsiuntė žinutę pokalbyje {call}",
@@ -504,9 +507,7 @@ OC.L10N.register(
     "Cancel" : "Atsisakyti",
     "Now" : "Dabar",
     "Unknown error occurred" : "Įvyko nežinoma klaida",
-    "Open Calendar" : "Atverti kalendorių",
     "Loading …" : "Įkeliama…",
-    "No upcoming events" : "Artėjančių įvykių nėra",
     "From" : "Nuo",
     "To" : "Kam",
     "Calendar" : "Kalendorius",
@@ -580,11 +581,11 @@ OC.L10N.register(
     "Restricted" : "Apribota",
     "Advanced permissions" : "Išplėstiniai leidimai",
     "Edit permissions" : "Taisyti leidimus",
+    "Meeting" : "Susitikimas",
     "Conversation settings" : "Pokalbio nustatymai",
     "Basic Info" : "Pagrindinė informacija",
     "Personal" : "Asmeniniai",
     "Setup overview" : "Sąrankos apžvalga",
-    "Meeting" : "Susitikimas",
     "Danger zone" : "Pavojinga zona",
     "Do you really want to leave \"{displayName}\"?" : "Ar tikrai norite išeiti iš „{displayName}“?",
     "Do you really want to delete \"{displayName}\"?" : "Ar tikrai norite ištrinti \"{displayName}\"?",
@@ -626,7 +627,11 @@ OC.L10N.register(
     "Log content" : "Žurnalo turinys",
     "Notifications" : "Pranešimai",
     "Notify about calls in this conversation" : "Pranešti apie skambučius šiame pokalbyje",
+    "Important conversation" : "Svarbus pokalbis",
+    "Join" : "Prisijungti",
     "Error while creating the conversation" : "Klaida kuriant pokalbį",
+    "Create a new conversation" : "Sukurti naują pokalbį",
+    "Join open conversations" : "Prisijungti prie atvirų pokalbių",
     "Create conversation" : "Sukurti pokalbį",
     "Enter your name" : "Įveskite savo vardą",
     "Submit name and join" : "Pateikti vardą ir prisijungti",
@@ -649,9 +654,8 @@ OC.L10N.register(
     "You have no unread messages." : "Jūs neturite neskaitytų žinučių.",
     "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
     "Conversation list" : "Pokalbių sąrašas",
+    "Unread messages" : "Neskaitytos žinutės",
     "Clear filters" : "Išvalyti filtrus",
-    "Create a new conversation" : "Sukurti naują pokalbį",
-    "Join open conversations" : "Prisijungti prie atvirų pokalbių",
     "Clear filter" : "Išvalyti filtrą",
     "Back to conversations" : "Atgal į pokalbius",
     "Talk settings" : "Pokalbių nustatymai",
@@ -691,7 +695,6 @@ OC.L10N.register(
     "Select a file" : "Pasirinkti failą",
     "Message sent" : "Žinutė išsiųsta",
     "Message deleted successfully" : "Žinutė sėkmingai ištrinta",
-    "Unread messages" : "Neskaitytos žinutės",
     "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
     "Set reminder for later today" : "Nustatyti priminimą šiandien vėliau",
     "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
@@ -775,7 +778,6 @@ OC.L10N.register(
     "Anonymous poll" : "Anoniminė apklausa",
     "Hide list of participants" : "Slėpti dalyvių sąrašą",
     "Show list of participants" : "Rodyti dalyvių sąrašą",
-    "Join" : "Prisijungti",
     "Back to main room" : "Atgal į pagrindinį kambarį",
     "Disable lobby" : "Išjungti laukimo salę",
     "moderator" : "moderatorius",
@@ -857,7 +859,9 @@ OC.L10N.register(
     "Raise hand (R)" : "Pakelti ranką (R)",
     "Lower hand" : "Nuleisti ranką",
     "Lower hand (R)" : "Nuleisti ranką (R)",
+    "Open Calendar" : "Atverti kalendorių",
     "Remove participant {name}" : "Šalinti dalyvį {name}",
+    "Keep" : "Palikti",
     "Open dialpad" : "Atverti numerio rinkiklį",
     "Select a region" : "Pasirinkti regioną",
     "Submit" : "Pateikti",
@@ -909,6 +913,7 @@ OC.L10N.register(
     "Team" : "Komanda",
     "You: {lastMessage}" : "Jūs: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "Leave this page" : "Išeiti iš šio puslapio",
     "Conversation password has been saved" : "Pokalbio slaptažodis įrašytas",
     "Conversation password has been removed" : "Pokalbio slaptažodis pašalintas",
     "Error occurred while saving conversation password" : "Įrašant pokalbio slaptažodį įvyko klaida",
@@ -916,7 +921,6 @@ OC.L10N.register(
     "Could not post message: {errorMessage}" : "Nepavyko paskelbti žinutės: {errorMessage}",
     "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
     "Invitations sent" : "Pakvietimai išsiųsti",
-    "Leave this page" : "Išeiti iš šio puslapio",
     "{guest} (guest)" : "{guest} (svečias)",
     "Poll \"{name}\" was created by {user}. Click to vote" : "{user} sukūrė apklausą, pavadinimu „{name}“. Spustelėkite norėdami dalyvauti",
     "Failed to add reaction" : "Nepavyko pridėti reakcijos",
