@@ -15,17 +15,18 @@ OC.L10N.register(
     "Guest" : "Viesis",
     "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Viens pret vienu sarunas tagad ir pastāvīgas, un tās vairs nevar nejauši pārveidot par kopu sarunām. Kā arī, kad viens no dalībniekiem pamet sarunu, tā vairs netiek automātiski izdzēsta. Tikai ja abi dalībnieki izies, saruna tiks izdzēsta no servera",
     "- In the sidebar you can now find an overview of the latest shared items" : "- Sānu joslā tagad var atrast pēdējo kopīgoto vienumu pārskatu",
+    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Sapulces uzlabotas ar viesu, kuri uzaicināti e-pastā, atpazīšanu, dalībnieku saraksta ievietošanu, aptauju melnraksti un dalībnieku sarakstu lejupielādēšanu.",
     "Talk updates ✅" : "Talk atjauninājumi ✅",
     "{actor} created the conversation" : "{actor} izveidoja sarunu",
-    "You created the conversation" : "Jūs izveidojāt sarunu",
+    "You created the conversation" : "Tu izveidoji sarunu",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pārdēvējāt sarunu no \"%1$s\" uz \"%2$s\"",
     "You started a call" : "Jūs sākāt zvanu",
     "{actor} started a call" : "{actor} sācis zvanu",
     "{actor} joined the call" : "{actor} pievienojies zvanam",
     "You joined the call" : "Jūs pievienojaties zvanam",
-    "{actor} left the call" : "{actor} atstājis zvanu",
-    "You left the call" : "Jūs atstājāt zvanu",
+    "{actor} left the call" : "{actor} pameta zvanu",
+    "You left the call" : "Tu pameti zvanu",
     "{actor} unlocked the conversation" : "{actor} atslēdz sarunu",
     "You unlocked the conversation" : "Jūs atslēdzāt sarunu",
     "{actor} locked the conversation" : "{actor} bloķē sarunu",
@@ -43,8 +44,8 @@ OC.L10N.register(
     "{actor} joined the conversation" : "{actor} pievienojās sarunai",
     "You added {user}" : "Tu pievienoji {user}",
     "{actor} added you" : "{actor} jūs pievienoja",
-    "You left the conversation" : "Jūs atstājāt sarunu",
-    "{actor} left the conversation" : "{actor} atstāja sarunu",
+    "You left the conversation" : "Tu pameti sarunu",
+    "{actor} left the conversation" : "{actor} pameta sarunu",
     "{actor} removed {user}" : "{actor} noņēma {user}",
     "You removed {user}" : "Jūs noņēmāt {user}",
     "{actor} removed you" : "{actor} jūs noņēma",
@@ -79,6 +80,8 @@ OC.L10N.register(
     "Dismiss notification" : "Noraidīt paziņojumu",
     "Accept" : "Pieņemt",
     "Decline" : "Noraidīt",
+    "New message" : "Jauna ziņa",
+    "Reminder" : "Atgādinājums",
     "{user} sent you a private message" : "{user} nosūtīja jums privātu ziņojumu",
     "{user} sent a message in conversation {call}" : "{user} nosūtīja ziņu sarunā {call}",
     "A deleted user sent a message in conversation {call}" : "Izdzēsts lietotājs nosūtīja ziņojumu sarunā {call}",
@@ -89,11 +92,14 @@ OC.L10N.register(
     "A guest mentioned you in conversation {call}" : "Kāds viesis jūs pieminēja sarunā {call}",
     "{user} invited you to a group conversation: {call}" : "{user} uzaicināja jūs uz grupas sarunu: {call}",
     "Join call" : "Pievienoties zvanam",
+    "{user} would like to talk with you" : "{user} vēlas runāt ar Tevi",
     "A group call has started in {call}" : "Grupas zvans ir sācies {call}",
     "Open settings" : "Atvērt iestatījumus",
     "error" : "kļūda",
     "Open Talk" : "Atvērt Talk",
     "Avatar image is not square" : "Avatar attēls nav kvadrāts",
+    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nepareizi uzvedās. Lūgums atgriezties vēlāk.",
+    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nav sasniedzams. Lūgums atgriezties vēlāk.",
     "Andorra" : "Andora",
     "United Arab Emirates" : "Apvienotie Arābu Emirāti",
     "Afghanistan" : "Afganistāna",
@@ -343,7 +349,7 @@ OC.L10N.register(
     "Saving …" : "Saglabā ...",
     "Saved!" : "Saglabāts!",
     "Limit to groups" : "Grupu ierobežojums",
-    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Ja ir atlasīta vismaz viena grupa, tikai personas no sarakstā minētajām grupām var piedalīties sarunās.",
+    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Ja ir atlasīta vismaz viena grupa, tikai cilvēki no sarakstā uzskaitītajām grupām var piedalīties sarunās.",
     "Guests can still join public conversations." : "Viesi joprojām var pievienoties publiskām sarunām.",
     "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Lietotāji, kas vairs nevar izmantot Talk, joprojām tiks uzrādīti kā dalībnieki viņu iepriekšējās sarunās, kā arī tiks paturētas viņu ziņas.",
     "Enabled" : "Iespējots",
@@ -377,15 +383,13 @@ OC.L10N.register(
     "Reset" : "Atiestatīt",
     "Back" : "Atpakaļ",
     "Cancel" : "Atcelt",
-    "Open Calendar" : "Atvērt kalendāru",
     "Loading …" : "Ielādē…",
-    "No upcoming events" : "Nav gaidāmu notikumu",
     "From" : "No",
     "To" : "Līdz",
     "Calendar" : "Kalendārs",
     "Attendees" : "Apmeklētāji",
     "Save" : "Saglabāt",
-    "No results" : "Nav rezultātu",
+    "No results" : "Nav iznākuma",
     "Done" : "Pabeigts",
     "Waiting for others to join the call …" : "Gaidot citus pievienoties zvanam …",
     "You can invite others in the participant tab of the sidebar" : "Sānjoslā, dalībnieku cilnē var uzaicināt citus dalībniekus",
@@ -401,24 +405,28 @@ OC.L10N.register(
     "Favorite" : "Izlasē",
     "Date:" : "Datums:",
     "Hide details" : "Slēpt detaļas",
-    "Show details" : "Rādīt detaļas",
+    "Show details" : "Rādīt informāciju",
     "Disable" : "Deaktivēt",
     "Enable" : "Iespējot",
     "Choose" : "Izvēlēties",
     "The file must be a PNG or JPG" : "Datnei jābūt PNG vai JPG",
     "Restricted" : "Ierobežota",
+    "Meeting" : "Tikšanās",
     "Personal" : "Personīgs",
     "Setup overview" : "Uzstādīšanas pārskats",
-    "Meeting" : "Tikšanās",
     "Leave conversation" : "Atstāt sarunu",
+    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Tiklīdz saruna ir pamesta, lai pievienotos slēgtai sarunai, ir nepieciešams uzaicinājums. Atvērtai sarunai var jebkurā brīdī pievienoties no jauna.",
     "No" : "Nē",
     "Yes" : "Jā",
     "Delete conversation" : "Izdzēst sarunu",
+    "_%n hour_::_%n hours_" : ["%n stundu","%n stunda","%n stundas"],
     "Password protection" : "Password protection",
     "Open conversation" : "Atvērt sarunu",
     "Edit" : "Labot",
     "Delete" : "Izdzēst",
     "Notifications" : "Paziņojumi",
+    "Join" : "Pievienoties",
+    "Create and copy link" : "Izveidot saiti un ievietot starpliktuvē",
     "Log in" : "Pieteikties",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
@@ -431,8 +439,11 @@ OC.L10N.register(
     "None" : "Nav",
     "Devices" : "Ierīces",
     "No audio" : "Nav audio",
+    "Invalid path selected" : "Atlasīts nederīgs ceļš",
     "Upload" : "Augšupielādēt",
     "Files" : "Datnes",
+    "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
+    "Set reminder for later today" : "Iestatīt atgādinājumu vēlākam šodien",
     "Reply" : "Atbildēt",
     "Go to file" : "Doties uz datni",
     "Translate" : "Tulkot",
@@ -440,14 +451,13 @@ OC.L10N.register(
     "Contact" : "Kontakts",
     "Today" : "Šodien",
     "Yesterday" : "Vakar",
-    "_%n day ago_::_%n days ago_" : ["%n dienas atpakaļ","%n dienas atpakaļ","%n dienām"],
+    "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "File to share" : "Kopīgojamā datne",
     "Upload from device" : "Augšupielādēt no ierīces",
     "New file" : "Jauna datne",
     "Send" : "Sūtīt",
     "Settings" : "Iestatījumi",
-    "Join" : "Pievienoties",
     "moderator" : "moderators",
     "guest" : "viesis",
     "Remove participant" : "Noņemt dalībnieku",
@@ -471,6 +481,8 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Search" : "Meklēt",
     "Start call" : "Sākt zvanu",
+    "All tasks done!" : "Visi uzdevumi paveikti.",
+    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} no %n uzdevumiem","{done} no %n uzdevuma","{done} no %n uzdevumiem"],
     "You are not allowed to enable screensharing" : "Nav ļauts iespējot ekrāna kopīgošanu",
     "No screensharing" : "Nav ekrāna kopīgošanas",
     "Screensharing options" : "Ekrāna kopīgošanas iespējas",
@@ -482,8 +494,12 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Ekrāna kopīgošanas uzsākšanas laikā atgadījās kļūda.",
     "Show your screen" : "Rādīt savu ekrānu",
     "Stop screensharing" : "Apturēt ekrāna kopīgošanu",
+    "Exit full screen (F)" : "Iziet no pilnekrāna (F)",
     "Grid view" : "Režģa izkārtojums",
     "Start recording" : "Uzsākt ierakstīšanu",
+    "Open Calendar" : "Atvērt kalendāru",
+    "Would you like to delete this conversation?" : "Vai izdzēst šo sarunu?",
+    "Keep" : "Paturēt",
     "Select a region" : "Izvēlieties reģionu",
     "Submit" : "Iesniegt",
     "Duplicate session" : "Pavairot sesiju",
@@ -491,13 +507,16 @@ OC.L10N.register(
     "User" : "Lietotājs",
     "Password" : "Parole",
     "API token" : "API pilnvara",
-    "Login" : "Autorizēties",
+    "Login" : "Pieteikumvārds",
     "Nickname" : "Iesauka",
     "Client ID" : "Klienta ID",
+    "Media" : "Informācijas nesēji",
     "Polls" : "Aptaujas",
     "Audio" : "Audio",
     "Other" : "Cits",
+    "Show all polls" : "Parādīt visas aptaujas",
     "Group" : "Grupa",
+    "You and {user0} left the call" : "Tu un {user0} pametāt zvanu",
     "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
     "Error while sharing file" : "Kļūda datnes kopīgošanā",
     "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
@@ -505,7 +524,7 @@ OC.L10N.register(
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, restartējiet pārlūkprogrammu, jo ir audio un video kļūme",
     "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
     "Please move your setup to HTTPS" : "Lūdzu, pārvietojiet iestatījumu uz HTTPS",
-    "Access to microphone & camera was denied" : "Piekļuve mikrofonam un kamerai tika liegta",
+    "Access to microphone & camera was denied" : "Tika noraidīta piekļuve mikrofonam un kamerai",
     "WebRTC is not supported in your browser" : "WebRTC netiek atbalstīta jūsu pārlūkprogrammā",
     "Please use a different browser like Firefox or Chrome" : "Lūdzu, izmantojiet citu pārlūkprogrammu, piemēram Firefox vai Chrome",
     "Error while accessing microphone & camera" : "Kļūda, piekļūstot mikrofonam un kamerai",
