@@ -167,6 +167,8 @@ OC.L10N.register(
     "Dismiss notification" : "Отфрли известување",
     "Accept" : "Прифати",
     "Decline" : "Одбиј",
+    "New message" : "Нова порака",
+    "Reminder" : "Потсетник",
     "Reminder: You in {call}" : "Потсетник: Вие во {call}",
     "Reminder: {user} in {call}" : "Потсетник: {user} во {call}",
     "Reminder: Deleted user in {call}" : "Потсетник: Избришан корисник во {call}",
@@ -378,7 +380,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "Свети Мартин (остров)",
     "Madagascar" : "Мадагаскар",
     "Marshall Islands" : "Маршалски Острови",
-    "Macedonia, the former Yugoslav Republic of" : "Македонија",
+    "North Macedonia" : "Македонија",
     "Mali" : "Мали",
     "Myanmar" : "Мјанмар",
     "Mongolia" : "Монголија",
@@ -573,7 +575,6 @@ OC.L10N.register(
     "Back" : "Назад",
     "Cancel" : "Откажи",
     "Add participant \"{user}\"" : "Додади учесник \"{user}\"",
-    "No upcoming events" : "Нема престојни настани",
     "From" : "Од",
     "To" : "До",
     "Calendar" : "Календар",
@@ -632,11 +633,11 @@ OC.L10N.register(
     "Restricted" : "Ограничена",
     "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Учесниците може да се придружуваат на повици, но не можат да овозможат аудио или видео, ниту да споделуваат екран додека модераторот рачно не им даде дозвола.",
     "Edit permissions" : "Уреди дозволи",
+    "Meeting" : "Средба",
     "Conversation settings" : "Параметри за разговор",
     "Basic Info" : "Основни информации",
     "Personal" : "Лично",
     "Always show the device preview screen before joining a call in this conversation." : "Секогаш прикажувај го екранот за преглед на уредот пред да се придружите на повик во овој разговор. ",
-    "Meeting" : "Средба",
     "Danger zone" : "Опасна зона",
     "Do you really want to delete \"{displayName}\"?" : "Дали навистина сакате да го избришете \"{displayName}\"?",
     "Be careful, these actions cannot be undone." : "Бидете внимателни, овие дејства не можат да повратат.",
@@ -662,7 +663,9 @@ OC.L10N.register(
     "Log content" : "Содржина на записот",
     "Notifications" : "Известувања",
     "Notify about calls in this conversation" : "Извести ме за повиците во овој разговор",
+    "Join" : "Приклучи се",
     "Error while creating the conversation" : "Грешка при креирање на разговор",
+    "Create a new conversation" : "Креирај нов разговор",
     "Create conversation" : "Креирајте разговор",
     "Enter your name" : "Внесете го вашето име",
     "Mark as read" : "Означи како прочитано",
@@ -675,7 +678,7 @@ OC.L10N.register(
     "No matches found" : "Не се пронајдени совпаѓања",
     "No conversations found" : "Нема пронајдено разговори",
     "An error occurred while performing the search" : "Настана грешка при обидот за пребарување",
-    "Create a new conversation" : "Креирај нов разговор",
+    "Unread messages" : "Непрочитани пораки",
     "Clear filter" : "Исчисти филтри",
     "Talk settings" : "Параметри за Talk",
     "Users" : "Корисници",
@@ -697,7 +700,6 @@ OC.L10N.register(
     "Upload" : "Прикачи",
     "Files" : "Датотеки",
     "Message sent" : "Пораката е испратена",
-    "Unread messages" : "Непрочитани пораки",
     "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
     "Set reminder for later today" : "Постави потсетник за денес покасно",
     "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
@@ -787,7 +789,6 @@ OC.L10N.register(
     "You voted for this option" : "Вие гласавте за оваа опција",
     "Submit vote" : "Гласај",
     "End poll" : "Затвори анкета",
-    "Join" : "Приклучи се",
     "Disable lobby" : "Оневозможи лоби",
     "Settings for participant \"{user}\"" : "Параметри за учесникот \"{user}\"",
     "Participant \"{user}\"" : "Учесник \"{user}\"",
@@ -917,6 +918,7 @@ OC.L10N.register(
     "Grid view" : "Мрежа",
     "Mute others" : "Занеми ги останатите",
     "Toggle full screen" : "Вклучи на цел екран",
+    "Keep" : "Задржи",
     "Select a region" : "Изберете регион",
     "Submit" : "Испрати",
     "Search …" : "Пребарај ...",
@@ -958,6 +960,9 @@ OC.L10N.register(
     "Team" : "Тим",
     "You: {lastMessage}" : "Ти: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Се обидувате да се приклучите на разговор додека имате активна сесија во друг прозорец или уред. Ова во моментов не е поддржано. Што сакаш да правиш?",
+    "Leave this page" : "Напушти ја оваа страна",
+    "Join here" : "Приклучи се овде",
     "Error while clearing conversation history" : "Грешка при чистење на историјата во разговорот",
     "Error occurred while allowing guests" : "Настана грешка при обидот за овозможување на гостите",
     "Error occurred while disallowing guests" : "Настана грешка при обидот за оневозможување на гостите",
@@ -968,9 +973,6 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Настана грешка при обидот за вчитување на учесниците",
     "Could not send invitation to {actorId}" : "Неможе да се ипспрати покана до {actorId}",
     "Invitations sent" : "Поканите се испратени",
-    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Се обидувате да се приклучите на разговор додека имате активна сесија во друг прозорец или уред. Ова во моментов не е поддржано. Што сакаш да правиш?",
-    "Leave this page" : "Напушти ја оваа страна",
-    "Join here" : "Приклучи се овде",
     "{guest} (guest)" : "{guest} (guest)",
     "An error occurred while submitting your vote" : "Настана грешка при гласање",
     "An error occurred while ending the poll" : "Настана грешка при затварање на анкетата",
