@@ -179,6 +179,8 @@ OC.L10N.register(
     "Call recording now available" : "L'enregistrament de sonada es ara disponible",
     "Accept" : "Acceptar",
     "Decline" : "Declinar",
+    "Reminder" : "Recòrd",
+    "Notification" : "Notificacion",
     "{user} reacted with {reaction}" : "{user} a reagit amb {reaction}",
     "{user} reacted with {reaction} in {call}" : "{user} a reagit amb {reaction} dins {call}",
     "{user} in {call}" : "{user} dins {call}",
@@ -387,7 +389,6 @@ OC.L10N.register(
     "Saint Martin (French part)" : "Sant Martin (francés)",
     "Madagascar" : "Madagascar",
     "Marshall Islands" : "Illas Marshall",
-    "Macedonia, the former Yugoslav Republic of" : "Republica de Macedònia del Nòrd",
     "Mali" : "Mali",
     "Myanmar" : "Myanmar",
     "Mongolia" : "Mongolia",
@@ -659,10 +660,10 @@ OC.L10N.register(
     "Restricted" : "Restrencha",
     "Advanced permissions" : "Permissions avançadas",
     "Edit permissions" : "Modificar las autorizacions",
+    "Meeting" : "Reünion",
     "Conversation settings" : "Paramètres de conversacion",
     "Personal" : "Personal",
     "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
-    "Meeting" : "Reünion",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zòna perilhosa",
     "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
@@ -690,8 +691,6 @@ OC.L10N.register(
     "Resend invitations" : "Tornar enviar las invitacions",
     "Error occurred when opening or limiting the conversation" : "Error en dobrissent o limitant la conversacion",
     "Open conversation" : "Dobrir la conversacion",
-    "Error occurred when restricting the conversation to moderator" : "Error pendent la restriccion de la conversacion al moderator",
-    "Error occurred when opening the conversation to everyone" : "Error pendent la dubertura de la conversacion a tot lo monde",
     "Start time has been updated" : "L'ora de debuta es estada actualizada",
     "Error occurred while updating start time" : "Error pendent la mesa a jorn de l’ora de debuta",
     "Meeting start time" : "Ora de debuta de la conferéncia",
@@ -713,7 +712,10 @@ OC.L10N.register(
     "Notifications" : "Notificacions",
     "Notify about calls in this conversation" : "Notificar las sonadas d’aquesta conversacion",
     "Recording Consent" : "Consentiment d'enregistrament",
+    "Join" : "Rejónher",
     "Error while creating the conversation" : "Error pendent la creacion de la conversacion",
+    "Create a new conversation" : "Crear una conversacion novèla",
+    "Unread mentions" : "Mencions pas legidas",
     "Create conversation" : "Crear conversacion",
     "Enter your name" : "Picatz vòstre nom",
     "Log in" : "Connexion",
@@ -728,9 +730,8 @@ OC.L10N.register(
     "You have no unread messages." : "Avètz un messatge pas legit.",
     "An error occurred while performing the search" : "Una error s'es producha en realizant la recèrca",
     "Conversation list" : "Lista de conversacion",
+    "Unread messages" : "Messatges pas legits",
     "Clear filters" : "Escafar los filtres",
-    "Create a new conversation" : "Crear una conversacion novèla",
-    "Unread mentions" : "Mencions pas legidas",
     "Talk settings" : "Paramètres Talk",
     "Users" : "Utilizaires",
     "Groups" : "Gropes",
@@ -761,7 +762,6 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Lo messatge a pas pogut èsser suprimit perque es tròp ancian",
     "Only normal chat messages can be deleted" : "Sonque los messatges de chat normal pòdon èsser suprimits",
     "An error occurred while deleting the message" : "Error pendent la supression del messatge",
-    "Unread messages" : "Messatges pas legits",
     "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Add a reaction to this message" : "Apondre una reaccion a aqueste messatge",
     "Reply" : "Respondre",
@@ -853,7 +853,6 @@ OC.L10N.register(
     "Submit vote" : "Enviar lo vòt",
     "Change your vote" : "Cambiar lo vòt",
     "End poll" : "Terminar lo sondatge",
-    "Join" : "Rejónher",
     "Stop session" : "Arrestar la session",
     "Disable lobby" : "Desactivar la sala d’espèra",
     "Settings for participant \"{user}\"" : "Paramètres pel participant « {user} »",
@@ -1053,9 +1052,13 @@ OC.L10N.register(
     "Group" : "Grop",
     "You: {lastMessage}" : "Vos : {lastMessage}",
     "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
+    "Leave this page" : "Quitar aquesta pagina",
+    "Join here" : "Rejónher aquí",
     "Error while clearing conversation history" : "Error pendent escafament de l’istoric de la conversacion",
     "Error occurred while allowing guests" : "Error en autorizant los convidats",
     "Error occurred while disallowing guests" : "Error en autorizant pas mai los convidats",
+    "Error occurred when restricting the conversation to moderator" : "Error pendent la restriccion de la conversacion al moderator",
+    "Error occurred when opening the conversation to everyone" : "Error pendent la dubertura de la conversacion a tot lo monde",
     "Conversation password has been saved" : "Lo senhal de conversacion es estat enregistrat",
     "Conversation password has been removed" : "Lo senhal de conversacion es estat suprimit",
     "Error occurred while saving conversation password" : "Error pendent l'enregistrament del senhal de la conversacion",
@@ -1067,8 +1070,6 @@ OC.L10N.register(
     "Could not send invitation to {actorId}" : "Mandadís impossible del convit a {actorId}",
     "Invitations sent" : "Invitacions enviadas",
     "Error occurred when sending invitations" : "Error en enviant las invitacions",
-    "Leave this page" : "Quitar aquesta pagina",
-    "Join here" : "Rejónher aquí",
     "{guest} (guest)" : "{guest} (convidat)",
     "Failed to add reaction" : "Apondon impossible de reaccion",
     "Failed to remove reaction" : "Supression impossibla de reaccion",
