@@ -41,6 +41,8 @@ OC.L10N.register(
     "Dismiss notification" : "Dispensar notificação",
     "Accept" : "Aceitar",
     "Decline" : "Recusar",
+    "New message" : "Nova mensagem",
+    "Reminder" : "Lembrete",
     "Join call" : "Juntar-se à chamada",
     "A group call has started in {call}" : "Uma chamada de grupo começou em {call}",
     "Open settings" : "Abrir definições",
@@ -299,11 +301,12 @@ OC.L10N.register(
     "Edit" : "Editar",
     "Delete" : "Apagar",
     "Notifications" : "Notificações",
+    "Join" : "Aderir",
+    "Create a new conversation" : "Criar nova conversa",
+    "Join open conversations" : "Juntar-me a conversas abertas",
     "Log in" : "Iniciar sessão",
     "Remove from favorites" : "Remover de favoritos",
     "Add to favorites" : "Adicionar aos favoritos",
-    "Create a new conversation" : "Criar nova conversa",
-    "Join open conversations" : "Juntar-me a conversas abertas",
     "Clear filter" : "Limpar filtro",
     "Talk settings" : "Definições do Falar",
     "Users" : "Utilizadores",
@@ -330,7 +333,6 @@ OC.L10N.register(
     "New file" : "Ficheiro novo",
     "Send" : "Enviar",
     "Settings" : "Definições",
-    "Join" : "Aderir",
     "moderator" : "moderador",
     "guest" : "convidado",
     "Remove participant" : "Remover participante",
@@ -341,10 +343,11 @@ OC.L10N.register(
     "Integrations" : "Integrações",
     "Searching …" : "À procura …",
     "Participants" : "Participantes",
-    "Search in {name}" : "Procurar em {name}",
     "Chat" : "Conversa",
     "Details" : "Detalhes",
+    "Search in {name}" : "Procurar em {name}",
     "Load more results" : "Mostrar mais resultados",
+    "Projects" : "Projectos",
     "No shared items" : "Sem itens partilhados",
     "Privacy" : "Privacidade",
     "Keyboard shortcuts" : "Atalhos de teclado",
@@ -358,6 +361,7 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
     "Grid view" : "Vista em grelha",
     "Download attendance list" : "Transferir lista de presenças",
+    "Keep" : "Manter",
     "Select a region" : "Selecione uma região",
     "Submit" : "Submeter",
     "User" : "Utilizador",
