@@ -46,10 +46,12 @@ use OCA\Talk\Exceptions\ParticipantProperty\PermissionsException;
 use OCA\Talk\Exceptions\UnauthorizedException;
 use OCA\Talk\Federation\BackendNotifier;
 use OCA\Talk\Federation\FederationManager;
+use OCA\Talk\GuestManager;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\AttendeeMapper;
 use OCA\Talk\Model\BreakoutRoom;
+use OCA\Talk\Model\InvitationList;
 use OCA\Talk\Model\SelectHelper;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Model\SessionMapper;
@@ -322,6 +324,46 @@ class ParticipantService {
 		$this->attendeeMapper->update($attendee);
 	}
 
+	/**
+	 * @param Participant $participant
+	 */
+	public function markConversationAsImportant(Participant $participant): void {
+		$attendee = $participant->getAttendee();
+		$attendee->setImportant(true);
+		$attendee->setLastAttendeeActivity($this->timeFactory->getTime());
+		$this->attendeeMapper->update($attendee);
+	}
+
+	/**
+	 * @param Participant $participant
+	 */
+	public function markConversationAsUnimportant(Participant $participant): void {
+		$attendee = $participant->getAttendee();
+		$attendee->setImportant(false);
+		$attendee->setLastAttendeeActivity($this->timeFactory->getTime());
+		$this->attendeeMapper->update($attendee);
+	}
+
+	/**
+	 * @param Participant $participant
+	 */
+	public function markConversationAsSensitive(Participant $participant): void {
+		$attendee = $participant->getAttendee();
+		$attendee->setSensitive(true);
+		$attendee->setLastAttendeeActivity($this->timeFactory->getTime());
+		$this->attendeeMapper->update($attendee);
+	}
+
+	/**
+	 * @param Participant $participant
+	 */
+	public function markConversationAsInsensitive(Participant $participant): void {
+		$attendee = $participant->getAttendee();
+		$attendee->setSensitive(false);
+		$attendee->setLastAttendeeActivity($this->timeFactory->getTime());
+		$this->attendeeMapper->update($attendee);
+	}
+
 	/**
 	 * @param RoomService $roomService
 	 * @param Room $room
@@ -423,7 +465,7 @@ class ParticipantService {
 	 * @throws InvalidPasswordException
 	 * @throws UnauthorizedException
 	 */
-	public function joinRoomAsNewGuest(RoomService $roomService, Room $room, string $password, bool $passedPasswordProtection = false, ?Participant $previousParticipant = null): Participant {
+	public function joinRoomAsNewGuest(RoomService $roomService, Room $room, string $password, bool $passedPasswordProtection = false, ?Participant $previousParticipant = null, ?string $displayName = null): Participant {
 		$event = new BeforeGuestJoinedRoomEvent($room, $password, $passedPasswordProtection);
 		$this->dispatcher->dispatchTyped($event);
 
@@ -452,6 +494,11 @@ class ParticipantService {
 			$attendee->setParticipantType(Participant::GUEST);
 			$attendee->setPermissions(Attendee::PERMISSIONS_DEFAULT);
 			$attendee->setLastReadMessage($lastMessage);
+
+			if ($displayName !== null && $displayName !== '') {
+				$attendee->setDisplayName($displayName);
+			}
+
 			$this->attendeeMapper->insert($attendee);
 
 			$attendeeEvent = new AttendeesAddedEvent($room, [$attendee]);
@@ -474,6 +521,65 @@ class ParticipantService {
 		return $participant;
 	}
 
+	public function addInvitationList(Room $room, InvitationList $invitationList, ?IUser $addedBy = null): void {
+		$participantsToAdd = [];
+		foreach ($invitationList->getUsers() as $user) {
+			$participantsToAdd[] = [
+				'actorType' => Attendee::ACTOR_USERS,
+				'actorId' => $user->getUID(),
+				'displayName' => $user->getDisplayName(),
+			];
+		}
+
+		foreach ($invitationList->getFederatedUsers() as $cloudId) {
+			$participantsToAdd[] = [
+				'actorType' => Attendee::ACTOR_FEDERATED_USERS,
+				'actorId' => $cloudId->getId(),
+				'displayName' => $cloudId->getDisplayId(),
+			];
+		}
+
+		foreach ($invitationList->getPhoneNumbers() as $phoneNumber) {
+			$participantsToAdd[] = [
+				'actorType' => Attendee::ACTOR_PHONES,
+				'actorId' => sha1($phoneNumber . '#' . $this->timeFactory->getTime()),
+				'displayName' => substr($phoneNumber, 0, -4) . '…', // FIXME Allow the UI to hand in a name (when selected from contacts?)
+				'phoneNumber' => $phoneNumber,
+			];
+		}
+
+		$existingParticipants = [];
+		if (!empty($participantsToAdd)) {
+			$attendees = $this->addUsers($room, $participantsToAdd, $addedBy);
+			$existingParticipants = array_map(static fn (Attendee $attendee): Participant => new Participant($room, $attendee, null), $attendees);
+		}
+
+		$emails = $invitationList->getEmails();
+		if (!empty($emails)) {
+			$guestManager = Server::get(GuestManager::class);
+			foreach ($emails as $email) {
+				$actorId = hash('sha256', $email);
+				try {
+					$this->getParticipantByActor($room, Attendee::ACTOR_EMAILS, $actorId);
+				} catch (ParticipantNotFoundException) {
+					$participant = $this->inviteEmailAddress($room, $actorId, $email);
+					try {
+						$guestManager->sendEmailInvitation($room, $participant);
+					} catch (\InvalidArgumentException) {
+					}
+				}
+			}
+		}
+
+		foreach ($invitationList->getGroup() as $group) {
+			$this->addGroup($room, $group, $existingParticipants);
+		}
+
+		foreach ($invitationList->getTeams() as $team) {
+			$this->addCircle($room, $team, $existingParticipants);
+		}
+	}
+
 	/**
 	 * @param Room $room
 	 * @param array $participants
@@ -640,9 +746,9 @@ class ParticipantService {
 	/**
 	 * @param Room $room
 	 * @param IGroup $group
-	 * @param Participant[] $existingParticipants
+	 * @param Participant[] &$existingParticipants
 	 */
-	public function addGroup(Room $room, IGroup $group, array $existingParticipants = []): void {
+	public function addGroup(Room $room, IGroup $group, array &$existingParticipants = []): void {
 		$usersInGroup = $group->getUsers();
 
 		if (empty($existingParticipants)) {
@@ -699,7 +805,10 @@ class ParticipantService {
 			$this->dispatcher->dispatchTyped($attendeeEvent);
 		}
 
-		$this->addUsers($room, $newParticipants, bansAlreadyChecked: true);
+		$attendees = $this->addUsers($room, $newParticipants, bansAlreadyChecked: true);
+		if (!empty($attendees)) {
+			$existingParticipants = array_merge(array_map(static fn (Attendee $attendee): Participant => new Participant($room, $attendee, null), $attendees), $existingParticipants);
+		}
 	}
 
 	/**
@@ -759,9 +868,9 @@ class ParticipantService {
 	/**
 	 * @param Room $room
 	 * @param Circle $circle
-	 * @param Participant[] $existingParticipants
+	 * @param Participant[] &$existingParticipants
 	 */
-	public function addCircle(Room $room, Circle $circle, array $existingParticipants = []): void {
+	public function addCircle(Room $room, Circle $circle, array &$existingParticipants = []): void {
 		$membersInCircle = $circle->getInheritedMembers();
 
 		if (empty($existingParticipants)) {
@@ -834,7 +943,10 @@ class ParticipantService {
 			$this->dispatcher->dispatchTyped($attendeeEvent);
 		}
 
-		$this->addUsers($room, $newParticipants, bansAlreadyChecked: true);
+		$attendees = $this->addUsers($room, $newParticipants, bansAlreadyChecked: true);
+		if (!empty($attendees)) {
+			$existingParticipants = array_merge(array_map(static fn (Attendee $attendee): Participant => new Participant($room, $attendee, null), $attendees), $existingParticipants);
+		}
 	}
 
 	public function inviteEmailAddress(Room $room, string $actorId, string $email, ?string $name = null): Participant {
@@ -1851,12 +1963,12 @@ class ParticipantService {
 
 	/**
 	 * @param Room $room
-	 * @return string[]
+	 * @return array<string, bool> (userId => isImportant)
 	 */
-	public function getParticipantUserIdsForCallNotifications(Room $room): array {
+	public function getParticipantUsersForCallNotifications(Room $room): array {
 		$query = $this->connection->getQueryBuilder();
 
-		$query->select('a.actor_id')
+		$query->select('a.actor_id', 'a.important')
 			->from('talk_attendees', 'a')
 			->leftJoin(
 				'a', 'talk_sessions', 's',
@@ -1893,14 +2005,14 @@ class ParticipantService {
 			);
 		}
 
-		$userIds = [];
+		$users = [];
 		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
-			$userIds[] = $row['actor_id'];
+			$users[$row['actor_id']] = (bool)$row['important'];
 		}
 		$result->closeCursor();
 
-		return $userIds;
+		return $users;
 	}
 
 	/**
